@@ -16,3 +16,9 @@ class Settings(object):
     monitor_log_path = 'monitor_log'
     refresh_interval = 3
     monitor_duration = 1
+    host = None
+    port = 8806
+    username = None
+    password = None
+    database = None
+    table = None
